Attribute VB_Name = "WIZUTIL"
' -------------------------------------------------------------------
' File: WIZUTIL.BAS
' Copyright (c) 1995 Vermeer Technologies, Inc.  All rights reserved.
' -------------------------------------------------------------------

Option Explicit

' list of files to be uploaded
Type FileInfo
    Name As String     ' name of disk file
    Path As String
    IsNew As Integer   ' is file being generated by wiz or not?
    Title As String    ' brief description of file
End Type
Global Files() As FileInfo
Global nFiles As Integer

' list of web meta-info variables
Type MetaVar
    Name As String
    Value As String
End Type
Global MetaVars() As MetaVar
Dim nMetaVars As Integer

#If Win16 Then
Declare Function GetPrivateProfileInt% Lib "Kernel" (ByVal lpAppName$, ByVal lpKeyName$, ByVal nDefault%, ByVal lpFileName$)
Declare Function GetPrivateProfileString% Lib "Kernel" (ByVal lpAppName$, ByVal lpKeyName$, ByVal lpDefault$, ByVal lpReturnedString$, ByVal nSize%, ByVal lpFileName$)
Declare Function WritePrivateProfileString% Lib "Kernel" (ByVal lpAppName$, ByVal lpKeyName$, ByVal lpString$, ByVal lpFileName$)
Declare Function SetWindowPos% Lib "User" (ByVal h%, ByVal hb%, ByVal x%, ByVal y%, ByVal cx%, ByVal cy%, ByVal f%)
Declare Function GetTempDrive% Lib "Kernel" (ByVal nDrive%)
Declare Function GetTempFileName% Lib "Kernel" (ByVal cDriveLetter%, ByVal lpPrefixString$, ByVal wUnique%, ByVal lpTempFileName$)
#Else
Declare Function GetPrivateProfileInt Lib "kernel32" Alias "GetPrivateProfileIntA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Long, ByVal lpFileName As String) As Long
Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lpFileName As String) As Long
Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Declare Function SetWindowPos Lib "user32" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long) As Long
Declare Function GetTempPath Lib "kernel32" Alias "GetTempPathA" (ByVal nBufferLength As Long, ByVal lpBuffer As String) As Long
Declare Function GetTempFileName Lib "kernel32" Alias "GetTempFileNameA" (ByVal lpszPath As String, ByVal lpPrefixString As String, ByVal wUnique As Long, ByVal lpTempFileName As String) As Long
#End If

' declare constants for changing window position and Z-order

Global Const SWP_NOMOVE = 2
Global Const SWP_NOSIZE = 1
Global Const HWND_TOPMOST = -1
Global Const HWND_NOTOPMOST = -2


Sub CenterFormOnScreen(f As Form)

    Dim x As Integer
    Dim y As Integer

    x = Screen.Width / 2 - f.Width / 2
    y = Screen.Height / 2 - f.Height / 2

    f.Move x, y

End Sub

Sub EndProcess()

    ' take down dialog, make it non-floating
    Progress.Hide
    MakeFloatingForm Progress, False
    DoEvents

End Sub

Function GetIniBool(key As String) As Integer

    Dim inifile As String
    Dim ret As Integer
    Dim strval As String

    strval = GetIniString(key)
    strval = LCase$(strval)

    Select Case strval
        Case "true"
            ret = True
        Case "yes"
            ret = True
        Case "1"
            ret = True
        Case "-1"
            ret = True
        Case Else
            ret = False
    End Select

    GetIniBool = ret

End Function

Function GetIniInt(key As String) As Integer

    Dim inifile As String
    Dim ret As Long
    
    inifile = App.Path & "\" & App.EXEName & ".ini"
    
    ret = GetPrivateProfileInt("Settings", key, -1, inifile)
    If ret = -1 Then
        ' means inifile couldn't be read or key not found;
        ' try looking in windows dir
        inifile = App.EXEName & ".ini"
        ret = GetPrivateProfileInt("Settings", key, -1, inifile)
        If ret = -1 Then ret = 0  ' no luck; use 0 for default, though
    End If

    GetIniInt = ret

End Function

Function GetIniString(key As String) As String

    Dim inifile As String
    Dim strval As String
    Dim valid As Long
    Dim size As Integer
    
    inifile = App.Path & "\" & App.EXEName & ".ini"
    
    strval = Space$(1024)
    size = Len(strval)

    valid = GetPrivateProfileString("Settings", key, "*NO-VALUE*", strval, size, inifile)
    ' discard trailing spaces and NULL character
    strval = Left$(strval, valid)

    If strval = "*NO-VALUE*" Then
        ' means INI file is unreadable or doesn't exist or key not found;
        ' try looking in Windows dir
        inifile = App.EXEName & ".ini"
        valid = GetPrivateProfileString("Settings", key, "*NO-VALUE*", strval, size, inifile)
        ' discard trailing spaces and NULL character
        strval = Left$(strval, valid)
        If strval = "*NO-VALUE*" Then strval = ""  ' no luck; return empty string
    End If

    GetIniString = strval

End Function

Sub InitFiles()

    ReDim Files(50)
    nFiles = 0

End Sub

Sub InitMetaVars()

    ReDim MetaNames(50)
    ReDim MetaVars(50)
    nMetaVars = 0

End Sub

Sub MakeFloatingForm(f As Form, yesno As Integer)

    Dim ret As Long

    If yesno Then
        ret = SetWindowPos(f.hwnd, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE Or SWP_NOSIZE)
    Else
        ret = SetWindowPos(f.hwnd, HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOMOVE Or SWP_NOSIZE)
    End If

End Sub

Function PackMetaInfoVars() As String

    Dim i As Integer
    Dim out As String

    out = ""

    For i = 0 To nMetaVars - 1
        out = out & MetaVars(i).Name & ":" & MetaVars(i).Value
        If (i + 1) < nMetaVars Then out = out & "|"
    Next i

    PackMetaInfoVars = out

End Function

Function ProcessAborted() As Integer

    If Progress.lblStatus.Caption = "CANCEL" Then
        ProcessAborted = True
    Else
        ProcessAborted = False
    End If

End Function

Sub SetIniBool(key As String, truth As Integer)

    Dim strval As String

    If truth Then
        strval = "True"
    Else
        strval = "False"
    End If

    SetIniString key, strval

End Sub

Sub SetIniInt(key As String, keyval As Integer)

    Dim strval As String

    strval = CStr(keyval)

    SetIniString key, strval
    
End Sub

Sub SetIniString(key As String, keyval As String)
    
    Dim inifile As String
    Dim ret As Long
    
    inifile = App.Path & "\" & App.EXEName & ".ini"

    ret = WritePrivateProfileString("Settings", key, keyval, inifile)
    If ret = 0 Then
        ' failure must mean that INI file can't be written
        ' in same dir as executable; so put it in Windows dir instead
        inifile = App.EXEName & ".ini"
        ret = WritePrivateProfileString("Settings", key, keyval, inifile)
        ' if that failed too, there's nothing we can do about it
    End If

End Sub

Function ShowProgress(item As String, position As Integer) As Integer

    If position < 0 Then
        ' hide it
        Progress.pnlMeter.Visible = False
    Else
        Progress.pnlMeter.Visible = True
        Progress.meter.Value = position
    End If

    Progress.lblItem.Caption = item
    Progress.Refresh

    DoEvents
    ' see if user has cancelled yet
    ShowProgress = ProcessAborted()

End Function

Sub Sleep(msecs As Integer)

    Dim btime, etime, interval

    If msecs <= 0 Then Exit Sub

    interval = msecs / 1000

    btime = Timer

    Do
        etime = Timer
        DoEvents
    Loop Until ((etime - btime) >= interval)

End Sub

Function TempFileName() As String

    Dim ret As Long
    Dim filename As String
    Dim dirname As String
    Dim drive As Integer
    Dim dloc As Integer

#If Win16 Then
    drive = GetTempDrive(0)
    filename = Space$(256)
    ret = GetTempFileName(drive, "wiz", 0, filename)
    If ret = 0 Then
        TempFileName = ""
    Else
        dloc = InStr(filename, ".tmp")
        If dloc = 0 Then
            dloc = InStr(filename, ".TMP")
        End If
        filename = Left$(filename, dloc + 3) ' get rid of trailing NULL
        TempFileName = filename
    End If
#Else
    dirname = Space$(256)
    ret = GetTempPath(256, dirname)
    If ret = 0 Then
        TempFileName = ""
    Else
        dirname = Left$(dirname, ret)
        filename = Space$(256)
        ret = GetTempFileName(dirname, "wiz", 0, filename)
        If ret = 0 Then
            TempFileName = ""
        Else
            dloc = InStr(filename, ".tmp")
            If dloc = 0 Then
                dloc = InStr(filename, ".TMP")
            End If
            filename = Left$(filename, dloc + 3) ' get rid of trailing NULL
            TempFileName = filename
        End If
    End If
#End If

End Function

Sub AddFile(filename As String, status As Integer, descr As String)

    Dim asize As Integer

    If nFiles >= UBound(Files) Then
        If UBound(Files) < 50 Then
            asize = 100
        Else
            asize = UBound(Files) * 2
        End If
        ReDim Files(asize)
    End If

    Files(nFiles).Name = filename
    Files(nFiles).IsNew = status
    If descr = "" Then
        Files(nFiles).Title = filename
    Else
        Files(nFiles).Title = descr
    End If
    Files(nFiles).Path = ""
    nFiles = nFiles + 1

End Sub

Sub AddMetaVar(varname As String, varvalue As String)

    Dim asize As Integer

    If nMetaVars >= UBound(MetaVars) Then
        If UBound(MetaVars) < 50 Then
            asize = 100
        Else
            asize = UBound(MetaVars) * 2
        End If
        ReDim MetaVars(asize)
    End If

    MetaVars(nMetaVars).Name = varname
    MetaVars(nMetaVars).Value = varvalue
    nMetaVars = nMetaVars + 1

End Sub

Sub BeginProcess(procname As String, minval As Integer, maxval As Integer, ShowMeter As Integer)

    Progress.Caption = procname
    Progress.lblItem = ""
    Progress.meter.Min = minval
    Progress.meter.Max = maxval
    Progress.meter.Value = minval
    Progress.lblStatus = ""

    Progress.pnlMeter.Visible = ShowMeter

    CenterFormOnScreen Progress

    ' show dialog non-modal, and make it float
    Progress.Show
    MakeFloatingForm Progress, True
    DoEvents

End Sub

